@@ -2,23 +2,23 @@
 import <-
 function(ms_filenames, ms_filetype, ...) UseMethod("import")
 
-import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA, targeted_fdr=0.01, spectral_prob=0.95, target_column="ADJNSAF", mergeruns=FALSE, sumruns=FALSE, replace_run_id=FALSE, filtertop=TRUE, removedecoys=TRUE, runsplit="~", ...) {
+import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA, averageruns=FALSE, sumruns=FALSE, mprophet_cutoff=0.01, openswath_superimpose_identifications=FALSE, openswath_replace_run_id=FALSE, openswath_filtertop=FALSE, openswath_removedecoys=TRUE, peptideprophet_cutoff=0.95, abacus_column="ADJNSAF", pepxml2csv_runsplit="~", ...) {
 	transition_intensity <- peptide_intensity <- protein_intensity <- NULL
 
-	if (!ms_filetype %in% c("skyline","openswath","mprophet","openmslfq","abacus","pepxml2csv")) {
-		stop("Please select a valid filetype. Options: \"skyline\", \"openswath\", \"mprophet\", \"openmslfq\", \"abacus\", \"pepxml2csv\"")
+	if (!ms_filetype %in% c("openswath","mprophet","openmslfq","skyline","abacus","pepxml2csv")) {
+		stop("Please select a valid filetype. Options:  \"mzidentml\", \"openswath\", \"mprophet\", \"openmslfq\", \"skyline\", \"abacus\", \"pepxml2csv\"")
 	}
 	
 	# ms_filenames must be provided as vector and are converted to a list
 	ms_filenames <- as.list(ms_filenames)
-	
+
 	# Skyline import is facilitated by the Transitions Results report
 	if (ms_filetype=="skyline") {
 		# Skyline specfic adapter
 		data.ms <- skyline_converter.import(ms_filenames)
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="transition_intensity")
-			data.ms$run_id <- "merged"
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="transition_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="transition_intensity")
@@ -30,11 +30,11 @@ import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA,
 	# OpenSWATH import is facilitated by using the output from either mProphet or the TOPPtool OpenSwathFeatureXMLToTSV
 	else if (ms_filetype=="openswath") {
 		# OpenSWATH specific adapter
-		data.ms <- openswath_converter.import(ms_filenames,fdr=targeted_fdr, replace_run_id=replace_run_id, filtertop = filtertop, removedecoys=removedecoys)
+		data.ms <- openswath_converter.import(ms_filenames,mprophet_cutoff=mprophet_cutoff,openswath_superimpose_identifications=openswath_superimpose_identifications, openswath_replace_run_id=openswath_replace_run_id, openswath_filtertop = openswath_filtertop, openswath_removedecoys=openswath_removedecoys)
 
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="transition_intensity")
-			data.ms$run_id <- "merged"
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="transition_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="transition_intensity")
@@ -45,11 +45,11 @@ import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA,
 	# mProphet import is facilitated by using the all_peakgroups.xls output
 	else if (ms_filetype=="mprophet") {
 		# mProphet specific adapter
-		data.ms <- mprophet_converter.import(ms_filenames,fdr=targeted_fdr, replace_run_id=replace_run_id, filtertop = filtertop, removedecoys=removedecoys)
+		data.ms <- mprophet_converter.import(ms_filenames,mprophet_cutoff=mprophet_cutoff, openswath_replace_run_id=openswath_replace_run_id, openswath_filtertop = openswath_filtertop, openswath_removedecoys=openswath_removedecoys)
 
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="transition_intensity")
-			data.ms$run_id <- "merged"
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="transition_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="transition_intensity")
@@ -61,9 +61,9 @@ import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA,
 	else if (ms_filetype=="openmslfq") {
 		# OpenMS LFQ specific adaptor
 		data.ms <- openmslfq_converter.import(ms_filenames)
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="peptide_intensity")
-			data.ms$run_id <- "merged"
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="peptide_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="peptide_intensity")
@@ -71,12 +71,12 @@ import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA,
 		}
 		data <- subset(data.ms,is.finite(peptide_intensity))
 	}
-	# Abacus protein import is facilitated from the Abacus with default output settings
+	# Abacus protein import is facilitated from Abacus with default output settings
 	else if (ms_filetype=="abacus") {
-		data.ms <- abacus_converter.import(ms_filenames, prob=spectral_prob, target_column=target_column)
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="protein_intensity")
-			data.ms$run_id <- "merged"
+		data.ms <- abacus_converter.import(ms_filenames, peptideprophet_cutoff=peptideprophet_cutoff, abacus_column=abacus_column)
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="protein_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="protein_intensity")
@@ -85,10 +85,10 @@ import.default <- function(ms_filenames, ms_filetype, concentration_filename=NA,
 		data <- subset(data.ms,is.finite(protein_intensity))
 	}
 	else if (ms_filetype=="pepxml2csv") {
-		data.ms <- pepxml2csv_converter.import(ms_filenames, prob=spectral_prob, runsplit=runsplit)
-		if (mergeruns==TRUE){
-			data.ms <- mergeruns.import(data.ms,target="protein_intensity")
-			data.ms$run_id <- "merged"
+		data.ms <- pepxml2csv_converter.import(ms_filenames, peptideprophet_cutoff=peptideprophet_cutoff, pepxml2csv_runsplit=pepxml2csv_runsplit)
+		if (averageruns==TRUE){
+			data.ms <- averageruns.import(data.ms,target="protein_intensity")
+			data.ms$run_id <- "averaged"
 		}
 		if (sumruns==TRUE){
 			data.ms <- sumruns.import(data.ms,target="protein_intensity")
@@ -153,10 +153,10 @@ skyline_converter.import <- function(ms_filenames, ...)  {
 	return(data.ms)
 }
 
-openswath_converter.import <- function(ms_filenames, fdr, replace_run_id, filtertop, removedecoys,...)  {
+openswath_converter.import <- function(ms_filenames, mprophet_cutoff, openswath_superimpose_identifications, openswath_replace_run_id, openswath_filtertop, openswath_removedecoys,...)  {
 	transition_code <- transition_code_intensity <- transition_id <- peptide_id <- transition_fragment <- m_score <- peak_group_rank <- decoy <- NULL
 
-	data.files = lapply(ms_filenames, read_table.import, replace_run_id=replace_run_id)
+	data.files = lapply(ms_filenames, read_table.import, openswath_replace_run_id=openswath_replace_run_id)
 	data.import <- data.table(do.call("rbind", data.files))
 
 
@@ -166,29 +166,35 @@ openswath_converter.import <- function(ms_filenames, fdr, replace_run_id, filter
 	# aLFQ headers
 	setnames(data.ms,c("run_id","ProteinName","FullPeptideName","m_score","peak_group_rank","Sequence","Charge","aggr_Fragment_Annotation","aggr_Peak_Area","decoy"),c("run_id","protein_id","peptide_id","m_score","peak_group_rank","peptide_sequence","precursor_charge","transition_code","transition_code_intensity","decoy"))
 	
-	setkeyv(data.ms,c("run_id","protein_id","peptide_id","m_score","peak_group_rank","peptide_sequence","precursor_charge","decoy"))
+	setkeyv(data.ms,c("run_id","transition_code","protein_id","peptide_id","m_score","peak_group_rank","peptide_sequence","precursor_charge","decoy"))
 
 	data.ms<-data.ms[, list("transition_fragment"=strsplit(transition_code,";")[[1]],"transition_intensity"=as.numeric(strsplit(transition_code_intensity,";")[[1]])), by=key(data.ms)]
 
 	data.ms[, transition_id:=paste(peptide_id,transition_fragment)]
 
-	# filter FDR
-	data.ms <- subset(data.ms, m_score <= fdr)
+	# filter mprophet_cutoff
+	if (openswath_superimpose_identifications) {
+		tcset <- unique(subset(data.ms, m_score <= mprophet_cutoff)$transition_code)
+		data.ms <- subset(data.ms, transition_code %in% tcset)
+	}
+	else {
+			data.ms <- subset(data.ms, m_score <= mprophet_cutoff)
+	}
 
 	# filter top peakgroup
-	if (filtertop) {
+	if (openswath_filtertop) {
 		data.ms <- subset(data.ms, peak_group_rank == 1)
 	}
 
 	# filter decoys
-	if (removedecoys) {
+	if (openswath_removedecoys) {
 		data.ms <- subset(data.ms, decoy == FALSE)
 	}
 
 	return(data.frame(data.ms[,c("run_id","protein_id","peptide_id","transition_id","peptide_sequence","precursor_charge","transition_intensity"), with = FALSE]))
 }
 
-mprophet_converter.import <- function(ms_filenames, fdr, replace_run_id, filtertop, removedecoys, ...)  {
+mprophet_converter.import <- function(ms_filenames, mprophet_cutoff, openswath_replace_run_id, openswath_filtertop, openswath_removedecoys, ...)  {
 	transition_code <- transition_code_intensity <- transition_id <- peptide_id <- transition_fragment <- m_score <- peak_group_rank <- decoy <- NULL
 
 	data.files = lapply(ms_filenames, read_table.import)
@@ -206,27 +212,27 @@ mprophet_converter.import <- function(ms_filenames, fdr, replace_run_id, filtert
 
 	data.ms[, transition_id:=paste(peptide_id,transition_fragment)]
 
-	# filter FDR
-	data.ms <- subset(data.ms, m_score <= fdr)
+	# filter mprophet_cutoff
+	data.ms <- subset(data.ms, m_score <= mprophet_cutoff)
 
 	# filter top peakgroup
-	if (filtertop) {
+	if (openswath_filtertop) {
 		data.ms <- subset(data.ms, peak_group_rank == 1)
 	}
 
 	# filter decoys
-	if (removedecoys) {
+	if (openswath_removedecoys) {
 		data.ms <- subset(data.ms, decoy == FALSE)
 	}
 
 	return(data.frame(data.ms[,c("run_id","protein_id","peptide_id","transition_id","peptide_sequence","precursor_charge","transition_intensity"), with = FALSE]))
 }
 
-read_table.import <- function(filename, replace_run_id = FALSE, ...) {
+read_table.import <- function(filename, openswath_replace_run_id = FALSE, ...) {
 	# helper function for mProphet to read runs. filenames are converted to the run_id.
 	data <- read.csv(filename, sep = "\t",stringsAsFactors=FALSE)
 
-	if (replace_run_id) {
+	if (openswath_replace_run_id) {
 		data$run_id <- filename
 	}
 
@@ -252,7 +258,7 @@ openmslfq_transform.import <- function(data, ...) {
 	
 	data.trans <- data.frame(run_id = NA, protein_id = NA, peptide_id = NA, peptide_sequence = NA, precursor_charge = NA, peptide_intensity = NA, stringsAsFactors=FALSE)[0,]
 
-	i <- length(names(data))-1
+	i <- length(names(data)) #-1
 	while( i > 4 ) {
 		data.trans <- rbind(data.trans,data.frame(run_id = names(data)[i], protein_id = data$protein, peptide_id = data$peptide, peptide_sequence = data$peptide, precursor_charge = data$charge, peptide_intensity = data[,i], stringsAsFactors=FALSE))
 	
@@ -262,36 +268,36 @@ openmslfq_transform.import <- function(data, ...) {
 	return(data.trans)
 }
 
-abacus_converter.import <- function(ms_filenames, prob, target_column, ...)  {
+abacus_converter.import <- function(ms_filenames, peptideprophet_cutoff, abacus_column, ...)  {
 	data.files = lapply(ms_filenames, read.csv, sep="\t", stringsAsFactors=FALSE)
 
-	data.trans<-lapply(data.files,function(X){abacus_transform.import(X,prob,target_column)})
+	data.trans<-lapply(data.files,function(X){abacus_transform.import(X,peptideprophet_cutoff,abacus_column)})
 
 	data.ms <- do.call("rbind", data.trans)
 
 	return(data.ms)
 }
-abacus_transform.import <- function(data, prob, target_column, ...)  {
+abacus_transform.import <- function(data, peptideprophet_cutoff, abacus_column, ...)  {
 	PW <- ISFWD <- NULL
 	data.re<-ldply(lapply(unlist(strsplit(names(data)[which(substr(names(data),1,3)!="ALL")][grepl("_ID", names(data)[which(substr(names(data),1,3)!="ALL")])],"_ID")),function(X){data.frame("RUN"=X,"PROTID"=data$PROTID,"PROTLEN"=data$PROTLEN,"ISFWD"=data$ISFWD,"PW"=data[,paste(X,"PW",sep="_")],"NUMSPECSTOT"=data[,paste(X,"NUMSPECSTOT",sep="_")],"TOTNSAF"=data[,paste(X,"TOTNSAF",sep="_")],"NUMSPECSUNIQ"=data[,paste(X,"NUMSPECSUNIQ",sep="_")],"UNIQNSAF"=data[,paste(X,"UNIQNSAF",sep="_")],"NUMSPECSADJ"=data[,paste(X,"NUMSPECSADJ",sep="_")],"ADJNSAF"=data[,paste(X,"ADJNSAF",sep="_")])}),data.frame)
 
-	data.filt <- subset(data.re, PW >= prob & ISFWD==1)
+	data.filt <- subset(data.re, PW >= peptideprophet_cutoff & ISFWD==1)
+
+	data.ms <- data.filt[,c("RUN","PROTID",abacus_column)]
 
-	data.ms <- data.filt[,c("RUN","PROTID",target_column)]
-							
 	names(data.ms) <- c("run_id","protein_id","protein_intensity")
 	
 	return(data.ms)
 }
 
-pepxml2csv_converter.import <- function(ms_filenames, prob, runsplit = "~", ...)  {
-	probability <- peptide_intensity <- NULL
+pepxml2csv_converter.import <- function(ms_filenames, peptideprophet_cutoff, pepxml2csv_runsplit = "~", ...)  {
+	peptideprophet_cutoff<- probability <- peptide_intensity <- NULL
 	data.files = lapply(ms_filenames, read_table.import)
 	data.import <- do.call("rbind", data.files)
 	data.import[which(is.na(data.import$modified_peptide)),]$modified_peptide<-data.import[which(is.na(data.import$modified_peptide)),]$peptide
-	data.import$run_id<-data.frame(do.call(rbind, strsplit(as.vector(data.import$spectrum), split = runsplit)),stringsAsFactors=FALSE)[,1]
+	data.import$run_id<-data.frame(do.call(rbind, strsplit(as.vector(data.import$spectrum), split = pepxml2csv_runsplit)),stringsAsFactors=FALSE)[,1]
 
-	# mProphet headers
+	# pepxml2csv headers
 	if ("probability_ip" %in% names(data.import)) {
 		data.ms <- data.table(data.import)[,c("run_id","assumed_charge","peptide","modified_peptide","protein","probability_ip"), with = FALSE]
 		setnames(data.ms,c("run_id","assumed_charge","peptide","modified_peptide","protein","probability_ip"),c("run_id","precursor_charge","peptide_sequence","peptide_id","protein_id","probability"))
@@ -301,8 +307,7 @@ pepxml2csv_converter.import <- function(ms_filenames, prob, runsplit = "~", ...)
 		setnames(data.ms,c("run_id","assumed_charge","peptide","modified_peptide","protein","probability_pp"),c("run_id","precursor_charge","peptide_sequence","peptide_id","protein_id","probability"))
 	}
 
-
-	data.ms<-subset(data.ms,probability >= prob)
+	data.ms<-subset(data.ms,probability >= peptideprophet_cutoff)
 	
 	setkeyv(data.ms,c("run_id","protein_id","peptide_id","peptide_sequence","precursor_charge"))
 
@@ -319,20 +324,20 @@ stripsequence.import <- function(X, ...) {
 
 }
 
-mergeruns.import <- function(data,target="transition_intensity", ...)  {
+averageruns.import <- function(data,target="transition_intensity", ...)  {
 	protein_id <- peptide_id <- transition_id <- peptide_sequence <- precursor_charge <- NULL
 
 	if (target=="transition_intensity") {
-		data.merged <- ddply(data, .(protein_id,peptide_id,transition_id,peptide_sequence,precursor_charge), function(X) {data.frame("transition_intensity" = mean(X$transition_intensity, na.rm = TRUE), stringsAsFactors=FALSE)})
+		data.averaged <- ddply(data, .(protein_id,peptide_id,transition_id,peptide_sequence,precursor_charge), function(X) {data.frame("transition_intensity" = mean(X$transition_intensity, na.rm = TRUE), stringsAsFactors=FALSE)})
 	}
 	else if (target=="peptide_intensity") {
-		data.merged <- ddply(data, .(protein_id,peptide_id,peptide_sequence,precursor_charge), function(X) {data.frame("peptide_intensity" = mean(X$peptide_intensity, na.rm = TRUE, stringsAsFactors=FALSE))})
+		data.averaged <- ddply(data, .(protein_id,peptide_id,peptide_sequence,precursor_charge), function(X) {data.frame("peptide_intensity" = mean(X$peptide_intensity, na.rm = TRUE, stringsAsFactors=FALSE))})
 	}
 	else if (target=="protein_intensity") {
-		data.merged <- ddply(data, .(protein_id), function(X) {data.frame("protein_intensity" = mean(X$protein_intensity, na.rm = TRUE, stringsAsFactors=FALSE))})
+		data.averaged <- ddply(data, .(protein_id), function(X) {data.frame("protein_intensity" = mean(X$protein_intensity, na.rm = TRUE, stringsAsFactors=FALSE))})
 	}
 	
-	return(data.merged)
+	return(data.averaged)
 }
 
 sumruns.import <- function(data,target="transition_intensity", ...)  {
